#!/bin/bash

# Copyright (C) since 2014 NTT DATA Corporation
#
# This program is free software; you can redistribute it and/or
# Modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation, version 2.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details

# bash configuration
SCRIPT_DIR=$(cd $(dirname $0);pwd)
PROG=`basename $0`

########################################
#  Local Variable
########################################

# script version
SCRIPT_VERSION="1.0.0"

########################################
# Function
########################################
#
# Message Logging
#
function Logging() {
	[ "x${QUIET}" != "xtrue" ] && echo "$1"
	/usr/bin/logger "${PROG} $1"
}

#
# show usage
#
function usage {
	echo "usage : ${PROG} -p PROFILE [-r REGION] -n QUEUENAME -q [--version] [--help]"
	echo "options:"
	echo "  -p PROFILE      set a aws cli profile name"
	echo "  -r REGION       set a aws cli region"
	echo "  -n QUEUENAME    set a aws cli sqs queue name"
	echo "  -q              quiet mode"
	echo "  --version       show version"
	echo "  --help          show usage"
}

########################################
# SHELL
########################################

# help chekc
for OPT in $@
do
	case $OPT in
		--version)
			echo ${SCRIPT_VERSION}
			exit 0
			;;
		--help)
			usage
			exit 0
			;;
	esac
done

# check parameters
while getopts p:r:n:q OPT
do
	case $OPT in
		p)
			PROFILE=$OPTARG
			;;
		r)
			REGION=$OPTARG
			;;
		n)
			QUEUENAME=$OPTARG
			;;
		q)
			QUIET=true
			;;
		*)
			usage
			exit 1
			;;
	esac
done

shift $((OPTIND - 1))

if [ "x${PROFILE}" == "x" ];then
	echo "option (-p) is not specified."
	usage
	exit 1
fi
Logging "target profile ${PROFILE}"

if [ "x${REGION}" != "x" ];then
	ARG_REGION="--r ${REGION}"
fi

if [ "x${QUEUENAME}" == "x" ];then
	echo "option (-n) is not specified."
	usage
	exit 1
fi
Logging "target queue name ${QUEUENAME}"

# queue url get
QUEUEURL=`aws --profile ${PROFILE} ${ARG_REGION} sqs get-queue-url --queue-name ${QUEUENAME} | jq -r '.QueueUrl'` 
if [ ! -n "${QUEUEURL}" ]; then
	echo "Failed to get the URL for the queue name ${QUEUENAME}"
 	exit 1
fi
Logging "QUEUEURL : ${QUEUEURL}"

# message send
SENDMESSAGE="SQS generalized in Hinemos

test messsage"

Logging "---------- send message ---------- "
Logging "${SENDMESSAGE}"
Logging "---------------------------------- "

aws --profile ${PROFILE} ${ARG_REGION} sqs send-message --queue-url ${QUEUEURL} --message-body "${SENDMESSAGE}"
RET=$?

if [ ${RET} -ne 0 ]; then
 	Logging "sqs message send failed"
	exit 1
fi
Logging "sqs message send success"

########################################
# Termination Processing
########################################
exit 0

